%% Simulating Gambler's Ruin
% David Ding
% November 27, 2020

clear;
close all;
clc;

%% Start of script
p = 1/2;
N = 20;
simCount = 1e4;
PiVec = zeros(N, 1);

for i = 1:N
   % Simulate Gambler's Ruin for each i from 1 to N each by 10K times.
   totalSuccess = 0;
   for k = 1:simCount
       totalSuccess = totalSuccess + gotToN(N, i, p);
   end
   PiVec(i) = totalSuccess;
end

PiVec = PiVec./simCount;

%% Display Result in Histogram
figure;
bar(PiVec);
titleStr = sprintf('Normalized Bar Graph of Fraction of Trials\nThat Got To N = %d for p = %f', N, p);
title(titleStr);
xlabel('State');
ylabelStr = sprintf('Fraction of Getting to N = %d', N);
ylabel(ylabelStr);

% Now add the theoretical line
hold on;
[PiTheory, inputX] = gotToNTheoretical(N, p);
plot(inputX, PiTheory,...
    'lineWidth', 2, ...
    'color', 'r');

legend('Empirical', 'Theoretical');